#!/bin/sh
#
# Setup vdesk to make some windows sticky
#

#------------------------------------------------------------------------------
# ie_executing - determines if a specific program is executing
#                sets variable isexec_count to the number of 
#                times the program was found executing under 
#                the current user
#------------------------------------------------------------------------------
is_executing()
{
    isexecp="$1"
    if test "$isexecp" = ""
    then
	usage "arg to is_executing() invalid, need search job"
    fi

    isexectmp1=$HOME/temp.$$.is_exec.1
    isexectmp2=$HOME/temp.$$.is_exec.2
    rm -f "$isexectmp1" "$isexectmp2"

    if test "$USER" = ""
    then
	USER=`whoami`
	export USER
    fi

    which $isexecp > /dev/null 2>&1
    if test "$?" -ne "0"
    then
	isexec_count=0
	return
    fi
    isexec_prog=`which $isexecp | sed 's/\//\\\\\//g;s/$/ /'`

    if test "$OS" = ""
    then
	OS=`uname -s`
	export OS
    fi

    case "$OS" in
	"FreeBSD")
	    isexec_ps="-a -o user,pid,command"
	    ;;
	"Linux")
	    isexec_ps="-A -o user,pid,command"
	    ;;
	"AIX")
	    isexec_ps="-A -o user,pid,command"
	    ;;
	"SunOS")
	    isexec_ps="-A -o user,pid,command"
	    ;;
	*)
	    usage "$OS not supported for is_executing"
	    exit 1
	    ;;
    esac

    ps $isexec_ps > "$isexectmp1"
    grep "$USER" "$isexectmp1" | awk '{printf("%s %s %s\n",$3,$1,$2)}' > "$isexectmp2"
    rm -f "$isexectmp1"

    isexec_count=`grep $isexec_prog "$isexectmp2" | wc -l | awk '{print $1}'`
    if test "$isexec_count" -eq "0"
    then
	isexec_count=`grep "$isexecp" "$isexectmp2" | wc -l | awk '{print $1}'`
    fi

    rm -f "$isexectmp2"

} # END: is_executing()

#------------------------------------------------------------------------------
# do_app() -- make an app sticky
#------------------------------------------------------------------------------
do_app()
{
    showmsg="$1"
    vwindow="$2"  #  window to map to, needed for gkrellm
    exename="$3"
    appname="$4"

    if test "$exename" != "iconbox"
    then
	is_executing "$exename"
    else
	isexec_count=1
    fi

    #--- special logic for rclock, uses date as the window name
    if test "$appname" = "rclock"
    then
	do_app_raw="Y"
	appname=`date '+%a %b %d'`
    else
	do_app_raw="N"
    fi

    #--- Process
    if test "$isexec_count" -gt "0"
    then
	id=`xwininfo -name "$appname" 2> /dev/null \
	    | grep 'Window id:' \
	    | awk '{print $4}'`
	geo=`xwininfo -name "$appname" 2> /dev/null \
	    | grep 'geometry' \
	    | awk '{print $2}'`
	if test "$id" != ""
	then
	    if test "$do_app_raw" = "Y"
	    then
		vdesk "$vwindow" "$appname"
		vdesk "$vwindow" "$id"
	    else
		vdesk "$vwindow" "$id"
	    fi
	    if test "$showmsg" = "Y"
	    then
		if test "$vwindow" = "0"
		then
		    echo "MAPPED: $exename / $appname -- $id -- sticky"
		else
		    echo "MAPPED: $exename / $appname -- $id -- window $vwindow"
		fi
		##echo $geo
	    fi
	else
	    if test "$showmsg" = "Y"
	    then
		echo "WARNING: could not determine ID of $exename -- $appname"
	    fi
	fi
    else
	if test "$showmsg" = "Y"
	then
	    echo "BYPASSED: $exename not running"
	fi
    fi

}  ## END: do_app()

###############################################################################
# start
###############################################################################
secs="$1"

if test "$secs" = ""
then
    sleep 4
else
    if test "$secs" -gt "0"
    then
	sleep $secs
    fi
fi

#------------------------------------------------------------------------------
# stick some apps
#------------------------------------------------------------------------------
#       | = Show process status
#       |   | = vdesk map to : 0 = sticky
#       |   |    | = This needs to be executing
#       |   |    |                  | = Name of the Window
#       |   |    |                  |
#       .   .    .                  .
do_app "N" "0" "xeyes"             "xeyes"
do_app "N" "0" "rclock"            "rclock"
do_app "Y" "0" "xclock"            "xclock"
do_app "N" "0" "xbiff"             "xbiff"
do_app "N" "0" "xload"             "xload"
do_app "N" "0" "stalonetray"       "stalonetray"
do_app "Y" "0" "iconbox"           "iconbox"

#------------------------------------------------------------------------------
# DONE
#------------------------------------------------------------------------------
exit 0
